@@ -1,6 +1,6 @@
 /************************************************************
  *
- * COPYRIGHT (C) HITACHI,LTD. 2002-2004
+ * COPYRIGHT (C) HITACHI,LTD. 2002-2005
  * WRITTEN BY HITACHI SYSTEMS DEVELOPMENT LABORATORY,
  *            HITACHI CENTRAL RESEARCH LABORATORY.
  *
@@ -31,14 +31,15 @@
 #define LKST_ETYPE_DEF_DESCRIPTIONS
 #include <linux/lkst_events.h>
 
-#define COPYRIGHT "COPYRIGHT (C) HITACHI,LTD. 2002-2004"
+#define COPYRIGHT "COPYRIGHT (C) HITACHI,LTD. 2002-2005"
 #define NAME	"lkstlogd"
-#define VERSION "1.7"
+#define VERSION "1.9"
 
 #define LOG_HEADER_SIZE \
 	(sizeof(log_header_t) +					\
 	sizeof(struct posix_log_entry) +			\
-	2*sizeof(int) + sizeof(char)*LKST_ARCH_NAME_LEN)
+	2*sizeof(int) + sizeof(char)*LKST_ARCH_NAME_LEN +	\
+	sizeof(struct lkst_log_record))
 
 
 //#define DEBUG
@@ -321,7 +322,8 @@ int owner_daemon()
 int child_daemon_main()
 {
 	/* check if daemon can write to log file.*/
-	close(setup_log_file());
+	if (log_file[0]!='\0')
+		close(setup_log_file());
 
 	/* set up sighandler */
 	if (signal(SIGHUP, SIG_DFL) == SIG_ERR ||
@@ -371,6 +373,7 @@ int setup_log_file(void)
 		errlog("Can't open %s.\n", tmpname);
 		exit(1);
 	}
+	infolog("Create logfile %s (maximum size = %d)\n",tmpname,info[cpu_id].limit_size);
 	/* write log header */
 	write_header(fd);
 	info[cpu_id].total_size = LOG_HEADER_SIZE;
@@ -424,18 +427,32 @@ void child_buf_read(void)
 void write_header(int fd)
 {
 	log_header_t logh = {
-		log_magic: LOGFILE_MAGIC,
-		log_version: 0
+		.log_magic = LOGFILE_MAGIC,
+		.log_version = 0,
+		.reserved1 = 1
 	};
 	struct posix_log_entry posix_entry = {
-		log_size: 2*sizeof(int) + sizeof(char)*LKST_ARCH_NAME_LEN,
-		log_format:PXLOG_BINARY
+		.log_size = 2*sizeof(int) + sizeof(char)*LKST_ARCH_NAME_LEN,
+		.log_format = PXLOG_BINARY,
+	};
+	struct lkst_log_record lkst_sync_time = {
+		.posix = {
+			.log_event_type = LKST_ETYPE_LKST_SYNC_TIME,
+			.log_size = (sizeof(u_int64_t)*4),
+			.log_magic = LKST_LOG_MAGIC_NUM,
+			.log_format = PXLOG_BINARY,
+			.log_time = {xtime.tv_sec,
+				     xtime.tv_usec*1000},
+		},
+		.log_arg1 = tsc,
+		.log_arg2 = cpu_hz,
 	};
 	write(fd, &logh, sizeof(log_header_t));
 	write(fd, &posix_entry, sizeof(struct posix_log_entry));
 	write(fd, &endian_big, sizeof(int));
 	write(fd, &buf_ver, sizeof(int));
 	write(fd, arch, sizeof(char)*LKST_ARCH_NAME_LEN);
+	write(fd, &lkst_sync_time, sizeof(struct lkst_log_record));
 }
 
 
@@ -455,7 +472,7 @@ void __inline__ calc_logtime(struct lkst_log_record *buffer, int read_count)
 		buf = &(buffer[j].posix.log_time);
 
 		log_cnt = ((u_int64_t) buf->tv_sec << 32) |
-			(unsigned long) buf->tv_nsec;
+			(unsigned long) (buf->tv_nsec & 0xffffffff);
 		
 		if (tsc > log_cnt){
 			diff_cnt = tsc - log_cnt;
@@ -497,7 +514,6 @@ int file_write(int fd, struct lkst_log_record *buffer, int res_size)
 
 	/* conver mc to time */
 	calc_logtime(buffer, read_count);
-
 	/* write to file */
 	return write(fd, buffer, sizeof(struct lkst_log_record)*read_count);
 }
@@ -545,6 +561,7 @@ void init_buffer(int devfd)
 				  lparam.id, lparam.next);
 		}
 	}
+	infolog("Create %d buffers on each CPUs (size=%d)\n",init_buf_num, init_buf_size);
 }
 
 int restore_buffer(int devfd)
@@ -638,6 +655,7 @@ void init_maskset(int devfd)
 		errlog("ioctl(LKST_IOC_MASKSET_SET) error: %s\n", strerror(errno));
 		exit(1);
 	}
+	infolog("Using maskset %d based on %d\n",maskset_id_daemon, maskset_id_prev);
 }
 
 int restore_maskset(int devfd)
