@@ -1,5 +1,5 @@
 #!/bin/sh
-# COPYRIGHT (C) HITACHI,LTD. 2003-2004
+# COPYRIGHT (C) HITACHI,LTD. 2003-2005
 # Written by M.Hiramatsu <hiramatu@sdl.hitachi.co.jp>
 
 LKSTMAJ=`cat /proc/devices | grep lkst | cut -f 1 -d " "`
@@ -15,3 +15,9 @@ while [ $i -le 31 ]; do
 /bin/mknod -m 0600 /dev/lkst$i c $LKSTMAJ `expr $i + 1`
 i=`expr $i + 1`
 done
+
+if [ -d /etc/makedev.d ]; then
+echo "#lkst device list" > /etc/makedev.d/lkst
+echo "c 600 root root $LKSTMAJ 0 1 1 lkst " >> /etc/makedev.d/lkst
+echo "c 600 root root $LKSTMAJ 1 1 32 lkst%d 0 " >> /etc/makedev.d/lkst
+fi
